@@ -31,6 +31,8 @@
  *
  *---------------------------------------------------------------*/
 
+#define DEMOD_C 1
+
 #include "direwolf.h"
 
 #include <stdlib.h>
@@ -63,11 +65,11 @@ static struct audio_s          *save_audio_config_p;
 
 // Current state of all the decoders.
 
-static struct demodulator_state_s demodulator_state[MAX_CHANS][MAX_SUBCHANS];
+static struct demodulator_state_s demodulator_state[MAX_RADIO_CHANS][MAX_SUBCHANS];
 
 
-static int sample_sum[MAX_CHANS][MAX_SUBCHANS];
-static int sample_count[MAX_CHANS][MAX_SUBCHANS];
+static int sample_sum[MAX_RADIO_CHANS][MAX_SUBCHANS];
+static int sample_count[MAX_RADIO_CHANS][MAX_SUBCHANS];
 
 
 /*------------------------------------------------------------------
@@ -100,7 +102,7 @@ int demod_init (struct audio_s *pa)
 
 	save_audio_config_p = pa;
 
-	for (chan = 0; chan < MAX_CHANS; chan++) {
+	for (chan = 0; chan < MAX_RADIO_CHANS; chan++) {
 
 	 if (save_audio_config_p->chan_medium[chan] == MEDIUM_RADIO) {
 
@@ -306,6 +308,7 @@ int demod_init (struct audio_s *pa)
 		    save_audio_config_p->adev[ACHAN2ADEV(chan)].samples_per_sec);
 	      if (save_audio_config_p->achan[chan].decimate != 1) 
 	        dw_printf (" / %d", save_audio_config_p->achan[chan].decimate);
+	      dw_printf (", Tx %s", layer2_tx[(int)(save_audio_config_p->achan[chan].layer2_xmit)]);
 	      if (save_audio_config_p->achan[chan].dtmf_decode != DTMF_DECODE_OFF) 
 	        dw_printf (", DTMF decoder enabled");
 	      dw_printf (".\n");
@@ -540,7 +543,7 @@ int demod_init (struct audio_s *pa)
 		    save_audio_config_p->adev[ACHAN2ADEV(chan)].samples_per_sec);
 	      if (save_audio_config_p->achan[chan].decimate != 1)
 	        dw_printf (" / %d", save_audio_config_p->achan[chan].decimate);
-
+	      dw_printf (", Tx %s", layer2_tx[(int)(save_audio_config_p->achan[chan].layer2_xmit)]);
 	      if (save_audio_config_p->achan[chan].v26_alternative == V26_B)
 	        dw_printf (", compatible with MFJ-2400");
 	      else
@@ -601,6 +604,7 @@ int demod_init (struct audio_s *pa)
 		    save_audio_config_p->adev[ACHAN2ADEV(chan)].samples_per_sec);
 	      if (save_audio_config_p->achan[chan].decimate != 1)
 	        dw_printf (" / %d", save_audio_config_p->achan[chan].decimate);
+	      dw_printf (", Tx %s", layer2_tx[(int)(save_audio_config_p->achan[chan].layer2_xmit)]);
 	      if (save_audio_config_p->achan[chan].dtmf_decode != DTMF_DECODE_OFF)
 	        dw_printf (", DTMF decoder enabled");
 	      dw_printf (".\n");
@@ -736,6 +740,7 @@ int demod_init (struct audio_s *pa)
 		    save_audio_config_p->achan[chan].profiles,
 		    save_audio_config_p->adev[ACHAN2ADEV(chan)].samples_per_sec,
 	            save_audio_config_p->achan[chan].upsample);
+	      dw_printf (", Tx %s", layer2_tx[(int)(save_audio_config_p->achan[chan].layer2_xmit)]);
 	      if (save_audio_config_p->achan[chan].dtmf_decode != DTMF_DECODE_OFF) 
 	        dw_printf (", DTMF decoder enabled");
 	      dw_printf (".\n");
@@ -812,7 +817,7 @@ int demod_init (struct audio_s *pa)
 
 	// Now the virtual channels.  FIXME:  could be single loop.
 
-	for (chan = MAX_CHANS; chan < MAX_TOTAL_CHANS; chan++) {
+	for (chan = MAX_RADIO_CHANS; chan < MAX_TOTAL_CHANS; chan++) {
 
 // FIXME dw_printf ("-------- virtual channel loop %d \n", chan);
 
@@ -927,7 +932,7 @@ int demod_get_sample (int a)
  *
  *--------------------------------------------------------------------*/
 
-static volatile int mute_input[MAX_CHANS];
+static volatile int mute_input[MAX_RADIO_CHANS];
 
 // New in 1.7.
 // A few people have a really bad audio cross talk situation where they receive their own transmissions.
@@ -939,7 +944,7 @@ static volatile int mute_input[MAX_CHANS];
 
 void demod_mute_input (int chan, int mute_during_xmit)
 {
-	assert (chan >= 0 && chan < MAX_CHANS);
+	assert (chan >= 0 && chan < MAX_RADIO_CHANS);
 	mute_input[chan] = mute_during_xmit;
 }
 
@@ -952,7 +957,7 @@ void demod_process_sample (int chan, int subchan, int sam)
 
 	struct demodulator_state_s *D;
 
-	assert (chan >= 0 && chan < MAX_CHANS);
+	assert (chan >= 0 && chan < MAX_RADIO_CHANS);
 	assert (subchan >= 0 && subchan < MAX_SUBCHANS);
 
 	if (mute_input[chan]) {
@@ -1066,7 +1071,7 @@ alevel_t demod_get_audio_level (int chan, int subchan)
 	struct demodulator_state_s *D;
 	alevel_t alevel;
 
-	assert (chan >= 0 && chan < MAX_CHANS);
+	assert (chan >= 0 && chan < MAX_RADIO_CHANS);
 	assert (subchan >= 0 && subchan < MAX_SUBCHANS);
 
 	/* We have to consider two different cases here. */
