@@ -1,7 +1,7 @@
 //
 //    This file is part of Dire Wolf, an amateur radio packet TNC.
 //
-//    Copyright (C) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019, 2020, 2021, 2023  John Langner, WB2OSZ
+//    Copyright (C) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2019, 2020, 2021, 2023, 2024. 2025  John Langner, WB2OSZ
 //
 //    This program is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -129,6 +129,8 @@
 #include "dwsock.h"
 #include "dns_sd_dw.h"
 #include "dlq.h"		// for fec_type_t definition.
+#include "deviceid.h"
+#include "nettnc.h"
 
 
 //static int idx_decoded = 0;
@@ -139,7 +141,7 @@ static BOOL cleanup_win (int);
 static void cleanup_linux (int);
 #endif
 
-static void usage ();
+static void usage (void);
 
 #if defined(__SSE__) && !defined(__APPLE__)
 
@@ -186,7 +188,7 @@ static int d_u_opt = 0;			/* "-d u" command line option to print UTF-8 also in h
 static int d_p_opt = 0;			/* "-d p" option for dumping packets over radio. */				
 
 static int q_h_opt = 0;			/* "-q h" Quiet, suppress the "heard" line with audio level. */
-static int q_d_opt = 0;			/* "-q d" Quiet, suppress the printing of decoded of APRS packets. */
+static int q_d_opt = 0;			/* "-q d" Quiet, suppress the printing of description of APRS packets. */
 
 static int A_opt_ais_to_obj = 0;	/* "-A" Convert received AIS to APRS "Object Report." */
 
@@ -227,6 +229,7 @@ int main (int argc, char *argv[])
 #endif
 	int d_x_opt = 1;	/* "-d x" option for FX.25.  Default minimal. Repeat for more detail.  -qx to silence. */
 	int d_2_opt = 0;	/* "-d 2" option for IL2P.  Default minimal. Repeat for more detail. */
+	int d_c_opt = 0;	/* "-d c" option for connected mode data link state machine. */
 
 	int aprstt_debug = 0;	/* "-d d" option for APRStt (think Dtmf) debug. */
 
@@ -298,28 +301,34 @@ int main (int argc, char *argv[])
 
 	// Might want to print OS version here.   For Windows, see:
 	// https://msdn.microsoft.com/en-us/library/ms724451(v=VS.85).aspx
+	// https://www.dennisbabkin.com/blog/?t=how-to-tell-the-real-version-of-windows-your-app-is-running-on
 
 	text_color_init(t_opt);
 	text_color_set(DW_COLOR_INFO);
-	//dw_printf ("Dire Wolf version %d.%d (%s) BETA TEST 7\n", MAJOR_VERSION, MINOR_VERSION, __DATE__);
-	//dw_printf ("Dire Wolf DEVELOPMENT version %d.%d %s (%s)\n", MAJOR_VERSION, MINOR_VERSION, "G", __DATE__);
-	dw_printf ("Dire Wolf version %d.%d\n", MAJOR_VERSION, MINOR_VERSION);
+	//dw_printf ("Dire Wolf version %d.%d (%s) BETA TEST 1\n", MAJOR_VERSION, MINOR_VERSION, __DATE__);
+	//dw_printf ("Dire Wolf DEVELOPMENT version %d.%d %s (%s)\n", MAJOR_VERSION, MINOR_VERSION, "E", __DATE__);
+	dw_printf ("Dire Wolf Release %d.%d.%d, November 2025\n", MAJOR_VERSION, MINOR_VERSION, PATCH_VERSION);
 
 
-#if defined(ENABLE_GPSD) || defined(USE_HAMLIB) || defined(USE_CM108) || USE_AVAHI_CLIENT || USE_MACOS_DNSSD
+#if defined(ENABLE_GPSD) || defined(USE_HAMLIB) || defined(USE_CM108) || USE_AVAHI_CLIENT || USE_MACOS_DNSSD || USE_GPIOD
 	dw_printf ("Includes optional support for: ");
-#if defined(ENABLE_GPSD)
+ #if defined(ENABLE_GPSD)
 	dw_printf (" gpsd");
-#endif
-#if defined(USE_HAMLIB)
+ #endif
+ #if defined(USE_HAMLIB)
 	dw_printf (" hamlib");
-#endif
-#if defined(USE_CM108)
+ #endif
+ #if defined(USE_CM108)
 	dw_printf (" cm108-ptt");
-#endif
-#if (USE_AVAHI_CLIENT|USE_MACOS_DNSSD)
+ #endif
+ #if defined(USE_GPIOD)
+ #define STRINGIFY(x) STRINGIFY2(x)
+ #define STRINGIFY2(x) #x
+        dw_printf (" libgpiod-%s", STRINGIFY(LIBGPIOD_VERSION));
+ #endif
+ #if (USE_AVAHI_CLIENT|USE_MACOS_DNSSD)
 	dw_printf (" dns-sd");
-#endif
+ #endif
 	dw_printf ("\n");
 #endif
 
@@ -333,6 +342,13 @@ int main (int argc, char *argv[])
 #endif
 
 
+// TODO: Display hardware and OS version to help with troubleshooting.
+// cat /proc/cpuinfo | grep ^Model
+// BSD, Deb?: /etc/os-release
+// /etc/issue
+
+
+
 /* 
  * Starting with version 0.9, the prebuilt Windows version 
  * requires a minimum of a Pentium 3 or equivalent so we can
@@ -386,6 +402,7 @@ int main (int argc, char *argv[])
 	    text_color_set(DW_COLOR_ERROR);
 	    for (int n=0; n<15; n++) {
 	      dw_printf ("\n");
+	      dw_printf ("Why are you running this as root user?.\n");
 	      dw_printf ("Dire Wolf requires only privileges available to ordinary users.\n");
 	      dw_printf ("Running this as root is an unnecessary security risk.\n");
 	      //SLEEP_SEC(1);
@@ -467,10 +484,10 @@ int main (int argc, char *argv[])
 						/* Also implies modem type based on speed. */
 						/* Special case "AIS" rather than number. */
 	    if (strcasecmp(optarg, "AIS") == 0) {
-	      B_opt = 12345;	// See special case below.
+	      B_opt = BAUD_SENTINEL_AIS;	// See special case below.
 	    }
 	    else if (strcasecmp(optarg, "EAS") == 0) {
-	      B_opt = 23456;	// See special case below.
+	      B_opt = BAUD_SENTINEL_EAS;	// See special case below.
 	    }
 	    else {
 	      B_opt = atoi(optarg);
@@ -554,7 +571,7 @@ int main (int argc, char *argv[])
       	    	break;
       	     }
 	    }
-	    if (x_opt_chan < 0 || x_opt_chan >= MAX_CHANS) {
+	    if (x_opt_chan < 0 || x_opt_chan >= MAX_RADIO_CHANS) {
 	      text_color_set(DW_COLOR_ERROR);
 	      dw_printf ("Invalid channel %d for -x. \n", x_opt_chan);
 	      text_color_set(DW_COLOR_INFO);
@@ -633,6 +650,7 @@ int main (int argc, char *argv[])
 #if USE_HAMLIB
 	      case 'h':  d_h_opt++; break;			// Hamlib verbose level.
 #endif
+	      case 'c':  d_c_opt++; break;			// Connected mode data link state machine
 	      case 'x':  d_x_opt++; break;			// FX.25
 	      case '2':  d_2_opt++; break;			// IL2P
 	      case 'd':	 aprstt_debug++; break;			// APRStt (mnemonic Dtmf)
@@ -826,13 +844,13 @@ int main (int argc, char *argv[])
 	      dw_printf ("Bit rate should be standard 4800 rather than specified %d.\n", audio_config.achan[0].baud);
 	    }
 	  }
-	  else if (audio_config.achan[0].baud == 12345) {
+	  else if (audio_config.achan[0].baud == BAUD_SENTINEL_AIS) {
 	    audio_config.achan[0].modem_type = MODEM_AIS;
 	    audio_config.achan[0].baud = 9600;
 	    audio_config.achan[0].mark_freq = 0;
 	    audio_config.achan[0].space_freq = 0;
 	  }
-	  else if (audio_config.achan[0].baud == 23456) {
+	  else if (audio_config.achan[0].baud == BAUD_SENTINEL_EAS) {
 	    audio_config.achan[0].modem_type = MODEM_EAS;
 	    audio_config.achan[0].baud = 521;	// Actually 520.83 but we have an integer field here.
 						// Will make more precise in afsk demod init.
@@ -982,6 +1000,7 @@ int main (int argc, char *argv[])
  * Files not supported at this time.
  * Can always "cat" the file and pipe it into stdin.
  */
+	deviceid_init();
 
 	err = audio_open (&audio_config);
 	if (err < 0) {
@@ -999,6 +1018,13 @@ int main (int argc, char *argv[])
 	fx25_init (d_x_opt);
 	il2p_init (d_2_opt);
 
+/*
+ * New in 1.8 - Allow a channel to be mapped to a network TNC rather than
+ * an internal modem and radio.
+ * I put it here so channel properties would come out in right order.
+ */
+	nettnc_init (&audio_config);
+
 /*
  * Initialize the touch tone decoder & APRStt gateway.
  */
@@ -1103,7 +1129,7 @@ int main (int argc, char *argv[])
 	igate_init (&audio_config, &igate_config, &digi_config, d_i_opt);
 	cdigipeater_init (&audio_config, &cdigi_config);
 	pfilter_init (&igate_config, d_f_opt);
-	ax25_link_init (&misc_config);
+	ax25_link_init (&misc_config, d_c_opt);
 
 /*
  * Provide the AGW & KISS socket interfaces for use by a client application.
@@ -1112,7 +1138,7 @@ int main (int argc, char *argv[])
 	kissnet_init (&misc_config);
 
 #if (USE_AVAHI_CLIENT|USE_MACOS_DNSSD)
-	if (misc_config.kiss_port > 0 && misc_config.dns_sd_enabled)
+	if (misc_config.kiss_port[0] > 0 && misc_config.dns_sd_enabled)
 	  dns_sd_announce(&misc_config);
 #endif
 
@@ -1162,7 +1188,10 @@ int main (int argc, char *argv[])
  *
  * Inputs:	chan	- Audio channel number, 0 or 1.
  *		subchan	- Which modem caught it.  
- *			  Special case -1 for DTMF decoder.
+ *			  Special cases:
+ *				-1 for DTMF decoder.
+ *				-2 for channel mapped to APRS-IS.
+ *				-3 for channel mapped to network TNC.
  *		slice	- Slicer which caught it.
  *		pp	- Packet handle.
  *		alevel	- Audio level, range of 0 - 100.
@@ -1193,7 +1222,7 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
 								// Can indicate FX.25/IL2P or fix_bits.
 
 	assert (chan >= 0 && chan < MAX_TOTAL_CHANS);		// TOTAL for virtual channels
-	assert (subchan >= -2 && subchan < MAX_SUBCHANS);
+	assert (subchan >= -3 && subchan < MAX_SUBCHANS);
 	assert (slice >= 0 && slice < MAX_SLICERS);
 	assert (pp != NULL);	// 1.1J+
      
@@ -1274,7 +1303,13 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
 
 	    ax25_get_addr_with_ssid(pp, h-1, probably_really);
 
-	    dw_printf ("%s (probably %s) audio level = %s  %s  %s\n", heard, probably_really, alevel_text, display_retries, spectrum);
+	    // audio level applies only for internal modem channels.
+	    if (subchan >=0) {
+	      dw_printf ("%s (probably %s) audio level = %s  %s  %s\n", heard, probably_really, alevel_text, display_retries, spectrum);
+	    }
+	    else {
+	      dw_printf ("%s (probably %s)\n", heard, probably_really);
+	    }
 
 	  }
 	  else if (strcmp(heard, "DTMF") == 0) {
@@ -1283,7 +1318,13 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
 	  }
 	  else {
 
-	    dw_printf ("%s audio level = %s  %s  %s\n", heard, alevel_text, display_retries, spectrum);
+	    // audio level applies only for internal modem channels.
+	    if (subchan >= 0) {
+	      dw_printf ("%s audio level = %s  %s  %s\n", heard, alevel_text, display_retries, spectrum);
+	    }
+	    else {
+	      dw_printf ("%s\n", heard);
+	    }
 	  }
 	 }
 	}
@@ -1297,10 +1338,12 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
 	if (alevel.rec > 110) {
 
 	  text_color_set(DW_COLOR_ERROR);
-	  dw_printf ("Audio input level is too high.  Reduce so most stations are around 50.\n");
+	  dw_printf ("Audio input level is too high. This may cause distortion and reduced decode performance.\n");
+	  dw_printf ("Solution is to decrease the audio input level.\n");
+	  dw_printf ("Setting audio input level so most stations are around 50 will provide good dyanmic range.\n");
 	}
 // FIXME: rather than checking for ichannel, how about checking medium==radio
-	else if (alevel.rec < 5 && chan != audio_config.igate_vchannel) {
+	else if (alevel.rec < 5 && chan != audio_config.igate_vchannel && subchan != -3) {
 
 	  text_color_set(DW_COLOR_ERROR);
 	  dw_printf ("Audio input level is too low.  Increase so most stations are around 50.\n");
@@ -1325,14 +1368,18 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
 	  strlcpy (ts, "", sizeof(ts));
 	}
 
-	if (subchan == -1) {
+	if (subchan == -1) {	// dtmf
 	  text_color_set(DW_COLOR_REC);
 	  dw_printf ("[%d.dtmf%s] ", chan, ts);
 	}
-	else if (subchan == -2) {
+	else if (subchan == -2) {	// APRS-IS
 	  text_color_set(DW_COLOR_REC);
 	  dw_printf ("[%d.is%s] ", chan, ts);
 	}
+	else if (subchan == -3) {	// nettnc
+	  text_color_set(DW_COLOR_REC);
+	  dw_printf ("[%d%s] ", chan, ts);
+	}
 	else {
 	  if (ax25_is_aprs(pp)) {
 	    text_color_set(DW_COLOR_REC);
@@ -1493,7 +1540,7 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
 		0, 0, 0, A.g_comment,	// freq, tone, offset
 		ais_obj_info, sizeof(ais_obj_info));
 
-	      snprintf (ais_obj_packet, sizeof(ais_obj_packet), "%s>%s%1d%1d:%s", A.g_src, APP_TOCALL, MAJOR_VERSION, MINOR_VERSION, ais_obj_info);
+	      snprintf (ais_obj_packet, sizeof(ais_obj_packet), "%s>%s%1d%1d,NOGATE:%s", A.g_src, APP_TOCALL, MAJOR_VERSION, MINOR_VERSION, ais_obj_info);
 
 	      dw_printf ("[%d.AIS] %s\n", chan, ais_obj_packet);
 
@@ -1609,9 +1656,10 @@ void app_process_rec_packet (int chan, int subchan, int slice, packet_t pp, alev
  * Use only those with correct CRC (or using FEC.)
  */
 
-	  if (retries == RETRY_NONE || fec_type == fec_type_fx25 || fec_type == fec_type_il2p) {
-
-	    cdigipeater (chan, pp);
+	  if (chan < MAX_RADIO_CHANS) {
+	    if (retries == RETRY_NONE || fec_type == fec_type_fx25 || fec_type == fec_type_il2p) {
+	      cdigipeater (chan, pp);
+	    }
 	  }
 	}
 
@@ -1656,7 +1704,7 @@ static void cleanup_linux (int x)
 
 
 
-static void usage (char **argv)
+static void usage (void)
 {
 	text_color_set(DW_COLOR_ERROR);
 
@@ -1703,12 +1751,13 @@ static void usage (char **argv)
 #if USE_HAMLIB
 	dw_printf ("       h             h = hamlib increase verbose level.\n");
 #endif
+	dw_printf ("       c             c = Connected mode data link state machine.\n");
 	dw_printf ("       x             x = FX.25 increase verbose level.\n");
 	dw_printf ("       2             2 = IL2P.\n");
 	dw_printf ("       d             d = APRStt (DTMF to APRS object translation).\n");
 	dw_printf ("    -q             Quiet (suppress output) options:\n");
 	dw_printf ("       h             h = Heard line with the audio level.\n");
-	dw_printf ("       d             d = Decoding of APRS packets.\n");
+	dw_printf ("       d             d = Description of APRS packets.\n");
 	dw_printf ("       x             x = Silence FX.25 information.\n");
 	dw_printf ("    -t n           Text colors.  0=disabled. 1=default.  2,3,4,... alternatives.\n");
 	dw_printf ("                     Use 9 to test compatibility with your terminal.\n");
