@@ -32,6 +32,11 @@
 #define _WIN32_WINNT 0x0501     /* Minimum OS version is XP. */
 #define WINVER       0x0501     /* Minimum OS version is XP. */
 
+// Other values are in Windows SDK sdkddkver.h
+//	0x0600 - Windows Vista
+//	0x0601 - Windows 7
+//	0x0A00 - Windows 10
+
 #include <winsock2.h>
 #include <windows.h>
 
@@ -56,15 +61,10 @@
  *
  *	ADevice 0:	channel 0
  *	ADevice 1:	left = 2, right = 3
- *
- * TODO1.2:  Look for any places that have
- *		for (ch=0; ch<MAX_CHANS; ch++) ...
- * and make sure they handle undefined channels correctly.
  */
 
 #define MAX_RADIO_CHANS ((MAX_ADEVS) * 2)
 
-#define MAX_CHANS MAX_RADIO_CHANS	// TODO: Replace all former  with latter to avoid confusion with following.
 
 #define MAX_TOTAL_CHANS 16		// v1.7 allows additional virtual channels which are connected
 					// to something other than radio modems.
@@ -77,7 +77,7 @@
  */
 
 #ifdef USE_HAMLIB
-#define MAX_RIGS MAX_CHANS
+#define MAX_RIGS MAX_RADIO_CHANS
 #endif
 
 /*
